@@ -196,6 +196,8 @@ football_features_set_colors <- function(plot_background = NULL,
 #'
 #' @export
 #'
+#' @importFrom rlang .data
+#'
 #' @examples
 #' \dontrun{
 #'   geom_football(league = "NFL", rotation = 270, display_range = "red_zone")
@@ -230,6 +232,19 @@ geom_football <- function(league,
   # Get the dimensions for the specified league
   field_params <- surface_dimensions[["football"]][[league]]
 
+  # If the provided league is not currently supported, alert the user. This will
+  # manifest by having the parameters list be NULL
+  if (is.null(field_params)) {
+    stop(
+      glue::glue(
+        "Sorry, {toupper(league)} is not a viable league to plot ",
+        "at this time. Please create an issue on GitHub with the league's ",
+        "playing surface specifications for the league to be added to the ",
+        "package"
+      )
+    )
+  }
+
   # Update the field parameters as necessary
   field_params <- utils::modifyList(field_params, field_updates)
 
@@ -1013,19 +1028,19 @@ geom_football <- function(league,
     field_plot <- field_plot +
       ggplot2::geom_polygon(
         data = bb_polygon,
-        ggplot2::aes_string(
-          x = "x",
-          y = "y"
+        ggplot2::aes(
+          x = .data$x,
+          y = .data$y
         ),
         fill = "#ffffff00"
       ) +
       ggfittext::geom_fit_text(
         data = yardage_marker_df,
-        ggplot2::aes_string(
-          xmin = "x_min",
-          xmax = "x_max",
-          ymin = "y_min",
-          ymax = "y_max"
+        ggplot2::aes(
+          xmin = .data$x_min,
+          xmax = .data$x_max,
+          ymin = .data$y_min,
+          ymax = .data$y_max
         ),
         label = yardage_marker_df$marking,
         angle = rotation + yardage_marker_df$marker_rotation,
@@ -1076,7 +1091,9 @@ geom_football <- function(league,
     (field_params$extra_apron_padding %or% 5)
 
   if (is.null(xlims)) {
-    xlims <- switch(tolower(display_range),
+    xlims <- switch(
+      tolower(display_range),
+
       # Full surface
       "full" = c(-half_field_length, half_field_length),
       "in_bounds_only" = c(
@@ -1170,7 +1187,9 @@ geom_football <- function(league,
   }
 
   if (is.null(ylims)) {
-    ylims <- switch(tolower(display_range),
+    ylims <- switch(
+      tolower(display_range),
+
       # Full surface
       "full" = c(-half_field_width, half_field_width),
       "in_bounds_only" = c(
